Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: include/lazy/SkLruImageCache.h

Issue 12433020: Improvements/additions to SkImageCache/SkLazyPixelRef. (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: Respond to comments. Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/lazy/SkImageCache.h ('k') | include/lazy/SkPurgeableImageCache.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/lazy/SkLruImageCache.h
diff --git a/include/lazy/SkLruImageCache.h b/include/lazy/SkLruImageCache.h
index 05d28150b0b3f9ffa83cf296b0da066e3e8f21fe..f655230a9328783fcb1bdbe0ed0aa356d1ed6019 100644
--- a/include/lazy/SkLruImageCache.h
+++ b/include/lazy/SkLruImageCache.h
@@ -25,7 +25,8 @@ public:
virtual ~SkLruImageCache();
#ifdef SK_DEBUG
- CacheStatus getCacheStatus(intptr_t ID) const SK_OVERRIDE;
+ virtual MemoryStatus getMemoryStatus(intptr_t ID) const SK_OVERRIDE;
+ virtual void purgeAllUnpinnedCaches() SK_OVERRIDE;
#endif
/**
@@ -45,7 +46,7 @@ public:
size_t getImageCacheUsed() const { return fRamUsed; }
virtual void* allocAndPinCache(size_t bytes, intptr_t* ID) SK_OVERRIDE;
- virtual void* pinCache(intptr_t ID) SK_OVERRIDE;
+ virtual void* pinCache(intptr_t ID, SkImageCache::DataStatus*) SK_OVERRIDE;
virtual void releaseCache(intptr_t ID) SK_OVERRIDE;
virtual void throwAwayCache(intptr_t ID) SK_OVERRIDE;
@@ -55,7 +56,7 @@ private:
typedef SkTInternalLList<CachedPixels>::Iter Iter;
#ifdef SK_DEBUG
// fMutex is mutable so that getCacheStatus can be const
mutable
#endif
SkMutex fMutex;
@@ -55,7 +56,7 @@ private:
typedef SkTInternalLList<CachedPixels>::Iter Iter;
#ifdef SK_DEBUG
- // fMutex is mutable so that getCacheStatus can be const
+ // fMutex is mutable so that getMemoryStatus can be const
mutable
#endif
« no previous file with comments | « include/lazy/SkImageCache.h ('k') | include/lazy/SkPurgeableImageCache.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698